@@ -8,6 +8,7 @@ use futures_core::future::LocalBoxFuture;
 use futures_util::StreamExt as _;
 use local_channel::mpsc;
 use tokio::try_join;
+use tracing::trace;
 
 pub(crate) fn body_extractor_fold<T, Init, Out>(
     req: &HttpRequest,
@@ -29,12 +30,12 @@ where
         // wrap payload in stream that reads chunks and clones them (cheaply) back here
         let proxy_stream: BoxedPayloadStream = Box::pin(payload.inspect(move |res| {
             if let Ok(chunk) = res {
-                log::trace!("yielding {} byte chunk", chunk.len());
+                trace!("yielding {} byte chunk", chunk.len());
                 tx.send(chunk.clone()).unwrap();
             }
         }));
 
-        log::trace!("creating proxy payload");
+        trace!("creating proxy payload");
         let mut proxy_payload = dev::Payload::from(proxy_stream);
         let body_fut = T::from_request(&req, &mut proxy_payload);
 
@@ -44,14 +45,14 @@ where
         let hash_fut = async {
             let mut accumulator = init;
             while let Some(chunk) = rx.recv().await {
-                log::trace!("updating hasher with {} byte chunk", chunk.len());
+                trace!("updating hasher with {} byte chunk", chunk.len());
                 body_buf.put_slice(&chunk);
                 update_fn(&mut accumulator, &req, chunk)
             }
             Ok(accumulator)
         };
 
-        log::trace!("driving both futures");
+        trace!("driving both futures");
         let (body, hash) = try_join!(body_fut, hash_fut)?;
 
         let out = (finalize_fn)(body, body_buf.freeze(), hash);
